From 72601d04fdfdd4c7597afcf1f6aab654bd99366c Mon Sep 17 00:00:00 2001
From: Wolfgang Denk <wd@denx.de>
Date: Sat, 16 May 2009 10:47:41 +0200
Subject: [PATCH] Rename ads5121 board into mpc5121ads

We rename the board so we use a consistent name in U-Boot and in
Linux.  Also, we use this opportunity to move the board into the
Freecale vendor directory.

Signed-off-by: Wolfgang Denk <wd@denx.de>
Cc: John Rigby <jcrigby@gmail.com>
---
 MAKEALL                                       |  2 +-
 Makefile                                      |  6 ++---
 .../mpc5121ads}/Makefile                      |  0
 .../{ads5121 => freescale/mpc5121ads}/README  |  0
 .../mpc5121ads}/config.mk                     |  0
 .../mpc5121ads/mpc5121ads.c}                  | 15 ++++++------
 include/configs/{ads5121.h => mpc5121ads.h}   | 24 +++++++++----------
 7 files changed, 24 insertions(+), 23 deletions(-)
 rename board/{ads5121 => freescale/mpc5121ads}/Makefile (100%)
 rename board/{ads5121 => freescale/mpc5121ads}/README (100%)
 rename board/{ads5121 => freescale/mpc5121ads}/config.mk (100%)
 rename board/{ads5121/ads5121.c => freescale/mpc5121ads/mpc5121ads.c} (97%)
 rename include/configs/{ads5121.h => mpc5121ads.h} (97%)

diff --git a/MAKEALL b/MAKEALL
index c98d03a579e..0e5f31531cb 100755
--- a/MAKEALL
+++ b/MAKEALL
@@ -77,7 +77,7 @@ LIST_5xxx="		\
 #########################################################################
 
 LIST_512x="		\
-	ads5121		\
+	mpc5121ads	\
 "
 
 #########################################################################
diff --git a/Makefile b/Makefile
index 4445b4b6a35..a43617e8ec1 100644
--- a/Makefile
+++ b/Makefile
@@ -821,14 +821,14 @@ v38b_config: unconfig
 ## MPC512x Systems
 #########################################################################
 
-ads5121_config \
-ads5121_rev2_config	\
+mpc5121ads_config \
+mpc5121ads_rev2_config	\
 	: unconfig
 	@mkdir -p $(obj)include
 	@if [ "$(findstring rev2,$@)" ] ; then \
 		echo "#define CONFIG_ADS5121_REV2 1" > $(obj)include/config.h; \
 	fi
-	@$(MKCONFIG) -a ads5121 ppc mpc512x ads5121
+	@$(MKCONFIG) -a mpc5121ads ppc mpc512x mpc5121ads freescale
 
 
 #########################################################################
diff --git a/board/ads5121/Makefile b/board/freescale/mpc5121ads/Makefile
similarity index 100%
rename from board/ads5121/Makefile
rename to board/freescale/mpc5121ads/Makefile
diff --git a/board/ads5121/README b/board/freescale/mpc5121ads/README
similarity index 100%
rename from board/ads5121/README
rename to board/freescale/mpc5121ads/README
diff --git a/board/ads5121/config.mk b/board/freescale/mpc5121ads/config.mk
similarity index 100%
rename from board/ads5121/config.mk
rename to board/freescale/mpc5121ads/config.mk
diff --git a/board/ads5121/ads5121.c b/board/freescale/mpc5121ads/mpc5121ads.c
similarity index 97%
rename from board/ads5121/ads5121.c
rename to board/freescale/mpc5121ads/mpc5121ads.c
index 405432c527e..e8eb491e3b4 100644
--- a/board/ads5121/ads5121.c
+++ b/board/freescale/mpc5121ads/mpc5121ads.c
@@ -33,6 +33,8 @@
 
 DECLARE_GLOBAL_DATA_PTR;
 
+extern int mpc5121_diu_init(void);
+
 /* Clocks in use */
 #define SCCR1_CLOCKS_EN	(CLOCK_SCCR1_CFG_EN |				\
 			 CLOCK_SCCR1_LPC_EN |				\
@@ -216,7 +218,6 @@ long int fixed_sdram (void)
 int misc_init_r(void)
 {
 	u8 tmp_val;
-	extern int mpc5121_diu_init(void);
 
 	/* Using this for DIU init before the driver in linux takes over
 	 *  Enable the TFP410 Encoder (I2C address 0x38)
@@ -238,13 +239,13 @@ int misc_init_r(void)
 	debug("DVI Encoder Read: 0x%02lx\n", tmp_val);
 
 #ifdef CONFIG_FSL_DIU_FB
-#if	!(defined(CONFIG_VIDEO) || defined(CONFIG_CFB_CONSOLE))
+# if	!(defined(CONFIG_VIDEO) || defined(CONFIG_CFB_CONSOLE))
 	mpc5121_diu_init();
+# endif
 #endif
-#endif
-
 	return 0;
 }
+
 static  iopin_t ioregs_init[] = {
 	/* FUNC1=FEC_RX_DV Sets Next 3 to FEC pads */
 	{
@@ -312,12 +313,12 @@ int checkboard (void)
 
 	printf ("Board: ADS5121 rev. 0x%04x (CPLD rev. 0x%02x)\n",
 		brd_rev, cpld_rev);
+
 	/* initialize function mux & slew rate IO inter alia on IO Pins  */
+	iopin_initialize(ioregs_init, ARRAY_SIZE(ioregs_init));
 
-	iopin_initialize(ioregs_init, sizeof(ioregs_init) / sizeof(ioregs_init[0]));
-	if (SVR_MJREV (im->sysconf.spridr) >= 2) {
+	if (SVR_MJREV (im->sysconf.spridr) >= 2)
 		iopin_initialize(rev2_silicon_pci_ioregs_init, 1);
-	}
 
 	return 0;
 }
diff --git a/include/configs/ads5121.h b/include/configs/mpc5121ads.h
similarity index 97%
rename from include/configs/ads5121.h
rename to include/configs/mpc5121ads.h
index b1420fa8886..9e3b0b7317d 100644
--- a/include/configs/ads5121.h
+++ b/include/configs/mpc5121ads.h
@@ -21,15 +21,15 @@
  */
 
 /*
  * ADS5121 board configuration file
  */
 
 #ifndef __CONFIG_H
 #define __CONFIG_H
 
-#define CONFIG_ADS5121 1
+#define CONFIG_MPC5121ADS 1
 /*
  * Memory map for the ADS5121 board:
  *
  * 0x0000_0000 - 0x0FFF_FFFF	DDR RAM (256 MB)
  * 0x3000_0000 - 0x3001_FFFF	SRAM (128 KB)
@@ -59,7 +59,7 @@
 
 /* CONFIG_PCI is defined at config time */
 
-#ifdef CONFIG_ADS5121_REV2
+#ifdef CONFIG_MPC5121ADS_REV2
 #define CONFIG_SYS_MPC512X_CLKIN	66000000	/* in Hz */
 #else
 #define CONFIG_SYS_MPC512X_CLKIN	33333333	/* in Hz */
@@ -78,7 +78,7 @@
 /*
  * DDR Setup - manually set all parameters as there's no SPD etc.
  */
-#ifdef CONFIG_ADS5121_REV2
+#ifdef CONFIG_MPC5121ADS_REV2
 #define CONFIG_SYS_DDR_SIZE		256		/* MB */
 #else
 #define CONFIG_SYS_DDR_SIZE		512		/* MB */
@@ -130,7 +130,7 @@
  *	[09:05]	DRAM tRP:
  *	[04:00] DRAM tRPA
  */
-#ifdef CONFIG_ADS5121_REV2
+#ifdef CONFIG_MPC5121ADS_REV2
 #define CONFIG_SYS_MDDRC_SYS_CFG	0xF8604A00
 #define CONFIG_SYS_MDDRC_SYS_CFG_RUN	0xE8604A00
 #define CONFIG_SYS_MDDRC_TIME_CFG1	0x54EC1168
@@ -433,8 +433,8 @@
  */
 #define CONFIG_TIMESTAMP
 
-#define CONFIG_HOSTNAME		ads5121
-#define CONFIG_BOOTFILE		ads5121/uImage
+#define CONFIG_HOSTNAME		mpc5121ads
+#define CONFIG_BOOTFILE		mpc5121ads/uImage
 #define CONFIG_ROOTPATH		/opt/eldk/ppc_6xx
 
 #define CONFIG_LOADADDR		400000	/* default location for tftp and bootm */
@@ -457,10 +457,10 @@
 	"kernel_addr=FFC40000\0"					\
 	"fdt_addr=FFEC0000\0"						\
 	"ramdisk_addr=FC040000\0"					\
-	"ramdiskfile=ads5121/uRamdisk\0"				\
-	"u-boot=ads5121/u-boot.bin\0"					\
-	"bootfile=ads5121/uImage\0"					\
-	"fdtfile=ads5121/ads5121.dtb\0"					\
+	"ramdiskfile=mpc5121ads/uRamdisk\0"				\
+	"u-boot=mpc5121ads/u-boot.bin\0"				\
+	"bootfile=mpc5121ads/uImage\0"					\
+	"fdtfile=mpc5121ads/mpc5121ads.dtb\0"				\
 	"rootpath=/opt/eldk/ppc_6xx\n"					\
 	"netdev=eth0\0"							\
 	"consdev=ttyPSC0\0"						\
@@ -21,15 +21,15 @@
 
 /*
- * ADS5121 board configuration file
+ * MPC5121ADS board configuration file
  */
 
@@ -21,15 +21,15 @@
 /*
- * Memory map for the ADS5121 board:
+ * Memory map for the MPC5121ADS board:
  *
  * 0x0000_0000 - 0x0FFF_FFFF	DDR RAM (256 MB)
-- 
GitLab